{% extends "sentry/index.html" %}

{% load sentry_helpers %}

{% block title %}Login | Django Sentry{% endblock %}

{% block body %}
	<div id="header">
		<div class="container">
				<h1><a href="{% url sentry %}"><span class="sentry-logo" title="Django Sentry"><img src="{% url sentry-media "images/sentry.png" %}" border=0/></span></a></h1>
			<h2>Login</h2>
		</div>
	</div> 
	<div id="content">
		<div class="container">
			<div id="body">
				<div class="login-area">
					<p>You must log in to continue</p>
				
					{% if form.errors %}
						<p class="error">Your username and password didn't match. Please try again.</p>
					{% endif %}

					<form method="post" action="" class="login-form">
						<input type="hidden" name="next" value="{{ next }}" />
					
						{% csrf_token %}
						<table>
							<colgroup>
								<col width="100px"/>
								<col/>
							</colgroup>
							<tr>
							    <td>{{ form.username.label_tag }}</td>
							    <td>{{ form.username }}</td>
							</tr>
							<tr>
							    <td>{{ form.password.label_tag }}</td>
							    <td>{{ form.password }}</td>
							</tr>
						</table>
						<div class="login-submit">
							<input type="submit" value="Login" />
						</div>
					</form>
				</div>
			</div>
		</div>
	</div>
	<div id="footer">
		<div class="container">
			Powered by sexy Django magic.
		</div>	
	</div> 
{% endblock %}
